@@ -6,6 +6,8 @@ use strict;
 use warnings;
 use base 'Exporter';
 
+use Test::More;
+
 our @EXPORT = qw(
     libmemcached_test_create
 );
@@ -13,6 +15,7 @@ our @EXPORT = qw(
 use Memcached::libmemcached qw(
     memcached_create
     memcached_server_add
+    memcached_get
 );
 
 sub libmemcached_test_create {
@@ -26,6 +29,14 @@ sub libmemcached_test_create {
     my $rc = memcached_server_add($memc, $opts);
     die "libmemcached_test_create: memcached_server_add($opts) failed: $rc" if $rc != 0;
 
+    # XXX ideally this should be a much 'simpler/safer' command
+    memcached_get($memc, "foo", my $flags=0, $rc=0);
+    if ($rc !~ /SUCCESS|NOT FOUND/) {
+        plan skip_all => "Can't talk to any memcached servers";
+        warn "Can't talk to any memcached servers ($rc)";
+        return undef;
+    }
+
     return $memc;
 }
 
